==> cloud-5.2.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/molecules/ActionButtonGroup.tsx <==
import LabelText from 'atoms/LabelText';
import {
    ACTION_BUTTON_LIST, DONT_SHOW_ACTION_ENTITY_TYPE_LIST, ROUTE_URL
} from 'constant/others/other';
import ENTITY_FORM_LIST from 'constant/templates/form/entity_form_template';
import useDrupalTranslation from 'hooks/drupal_translation';
import MenuTemplate from 'model/MenuTemplate';
import { Button, Form } from 'react-bootstrap';
import { Link } from 'react-router-dom';
import { cspToLabel, entityNameToLabel } from 'service/string';

/**
 * Calculate the list of action buttons to display.
 *
 * @param menuTemplate The template of form menu.
 * @param cloudContext The Cloud Context.
 */
const calcActionButtonList = (menuTemplate: MenuTemplate, cloudContext: string) => {
  const actionTypeList = ENTITY_FORM_LIST.filter((r) => {
    return r.cloudServiceProvider === menuTemplate.cloudServiceProvider
      && r.entityName === menuTemplate.entityName;
  }).map((r) => r.actionType);

  const buttonList = ACTION_BUTTON_LIST
  .filter((r) => {
    return actionTypeList.includes(r.actionType);
  })
  .map((r) => {
    const to = `/${menuTemplate.cloudServiceProvider}/${cloudContext}/${menuTemplate.entityName}/${r.actionType}`;
    const actionLabel = r.label;
    const cloudServiceProviderLabel = cspToLabel(menuTemplate.cloudServiceProvider);
    const entitytype = menuTemplate.entityName;
    return {
      to,
      action: actionLabel,
      cloudServiceProvider: cloudServiceProviderLabel,
      type: entityNameToLabel(entitytype),
    };
  });

  return menuTemplate.entityName === 'instance'
    ? [{
      to: `/${menuTemplate.cloudServiceProvider}/${cloudContext}/server_template`,
      action: 'Add | Launch',
      cloudServiceProvider: cspToLabel(menuTemplate.cloudServiceProvider),
      type: entityNameToLabel('instance'),
    }, ...buttonList]
    : buttonList;
}

/**
 * The button of creating cloud entity.
 *
 * @param menuTemplate The template of form menu.
 * @param cloudContext The Cloud Context.
 */
const ActionButtonGroup = ({ menuTemplate, cloudContext }: {
  menuTemplate: MenuTemplate,
  cloudContext: string
}) => {

  const { t } = useDrupalTranslation();

  /**
   * Entity type that does not display Action buttons in ListView.
   */
  if (DONT_SHOW_ACTION_ENTITY_TYPE_LIST.filter((r) => {
    return r.cloudServiceProvider === menuTemplate.cloudServiceProvider
      && r.entityName === menuTemplate.entityName;
  }).length >= 1) {
    return <></>;
  }

  /**
   * List of action buttons to display.
   */
  const actionButtonList = calcActionButtonList(menuTemplate, cloudContext);

  /**
   * Function to update the entity list.
   */
  const refresh = async () => {
    const url = `/clouds/${menuTemplate.cloudServiceProvider}/${cloudContext}/${menuTemplate.entityName}/update`;

    const response = await fetch(url, { method: 'POST' });
    if (response.ok) {
      window.location.href = `${ROUTE_URL}/${menuTemplate.cloudServiceProvider}/${cloudContext}/${menuTemplate.entityName}`;
    }
  }

  return <Form.Group>
    {
      actionButtonList.map((r) => {
        return <Link className="btn btn-primary" key={r.to} to={r.to}>
          <LabelText text={`${r.action} @cloudServiceProvider @entityName`}
            args={{
              '@cloudServiceProvider': r.cloudServiceProvider,
              '@entityName': r.type,
            }}
          />
        </Link>;
      })
    }
    <Button onClick={refresh}>
      <LabelText text="Refresh" />
    </Button>
  </Form.Group>;

}

export default ActionButtonGroup;

==> cloud-5.4.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/molecules/ActionButtonGroup.tsx <==
import LabelText from 'atoms/LabelText';
import { ACTION_BUTTON_LIST, DONT_SHOW_ACTION_ENTITY_TYPE_LIST } from 'constant/others/other';
import ENTITY_FORM_LIST from 'constant/templates/form/entity_form_template';
import useDrupalJsonApi from 'hooks/drupal_jsonapi';
import useDrupalTranslation from 'hooks/drupal_translation';
import MenuTemplate from 'model/MenuTemplate';
import { useContext, useState } from 'react';
import { Button, Form } from 'react-bootstrap';
import { Link, useHistory } from 'react-router-dom';
import { AppContext } from 'service/state';
import { cspToLabel, entityNameToLabel } from 'service/string';

/**
 * Calculate the list of action buttons to display.
 *
 * @param menuTemplate The template of form menu.
 * @param cloudContext The Cloud Context.
 */
const calcActionButtonList = (menuTemplate: MenuTemplate, cloudContext: string) => {
  const actionTypeList = ENTITY_FORM_LIST.filter((r) => {
    return r.cloudServiceProvider === menuTemplate.cloudServiceProvider
      && r.entityName === menuTemplate.entityName;
  }).map((r) => r.actionType);

  const buttonList = ACTION_BUTTON_LIST
  .filter((r) => {
    return actionTypeList.includes(r.actionType);
  })
  .map((r) => {
    const to = `/${menuTemplate.cloudServiceProvider}/${cloudContext}/${menuTemplate.entityName}/${r.actionType}`;
    const actionLabel = r.label;
    const cloudServiceProviderLabel = cspToLabel(menuTemplate.cloudServiceProvider);
    const entitytype = menuTemplate.entityName;
    return {
      to,
      action: actionLabel,
      cloudServiceProvider: cloudServiceProviderLabel,
      type: entityNameToLabel(entitytype),
    };
  });

  return menuTemplate.entityName === 'instance'
    ? [{
      to: `/${menuTemplate.cloudServiceProvider}/${cloudContext}/server_template`,
      action: 'Add | Launch',
      cloudServiceProvider: cspToLabel(menuTemplate.cloudServiceProvider),
      type: entityNameToLabel('instance'),
    }, ...buttonList]
    : buttonList;
}

/**
 * The button of creating cloud entity.
 *
 * @param menuTemplate The template of form menu.
 * @param cloudContext The Cloud Context.
 */
const ActionButtonGroup = ({ menuTemplate, cloudContext }: {
  menuTemplate: MenuTemplate,
  cloudContext: string
}) => {

  const { t } = useDrupalTranslation();
  const { addMessage, addErrorMessage } = useContext(AppContext);
  const [isRefreshing, setRefreshing] = useState(false);
  const history = useHistory();
  const { resetFetchCache } = useDrupalJsonApi();

  /**
   * Entity type that does not display Action buttons in ListView.
   */
  if (DONT_SHOW_ACTION_ENTITY_TYPE_LIST.filter((r) => {
    return r.cloudServiceProvider === menuTemplate.cloudServiceProvider
      && r.entityName === menuTemplate.entityName;
  }).length >= 1) {
    return <></>;
  }

  /**
   * List of action buttons to display.
   */
  const actionButtonList = calcActionButtonList(menuTemplate, cloudContext);

  /**
   * Function to update the entity list.
   */
  const refresh = async () => {
    setRefreshing(true);
    const url = `/clouds/${menuTemplate.cloudServiceProvider}/${cloudContext}/${menuTemplate.entityName}/update`;

    const response = await fetch(url, { method: 'POST' });
    setRefreshing(false);
    if (response.ok) {
      addMessage(t('Updated @entityName.', {
        '@entityName': entityNameToLabel(menuTemplate.entityName),
      }));
      resetFetchCache();
      history.push(`/${menuTemplate.cloudServiceProvider}/${cloudContext}/${menuTemplate.entityName}`);
    } else {
      addErrorMessage(t('Unable to update @entityName.', {
        '@entityName': entityNameToLabel(menuTemplate.entityName),
      }));
    }
  }

  return <Form.Group>
    {
      actionButtonList.map((r) => {
        return <Link className="btn btn-primary" key={r.to} to={r.to}>
          <LabelText text={`${r.action} @cloudServiceProvider @entityName`}
            args={{
              '@cloudServiceProvider': r.cloudServiceProvider,
              '@entityName': r.type,
            }}
          />
        </Link>;
      })
    }
    <Button variant={isRefreshing ? 'secondary' : 'primary'}
      disabled={isRefreshing}
      onClick={refresh}>
      <LabelText text={
        isRefreshing ? 'Refreshing...' : 'Refresh'
      } />
    </Button>
  </Form.Group>;

}

export default ActionButtonGroup;
